function [elements,t_set] = Maze_gen( sz,tangling_steps,growing_steps )

% % Maze_gen 
% This function generates a maze using a process that iterativly replaces
% each maze component with other random component. The process starts with 
% a single path from start to the finish. MY replacing components the maze becomes more
% complex. 
% This process is divided into two precosses: 
% *   a tangleling process that repleces maze components in a way that makes
%     the maze longer and more complicated but adds no new intersections or
%     forks
% *   a growing process that replaces maze components in a way that is more
%     likelly to add intersections and create new branches
% 
% USAGE:
% [elements,t_set] = Maze_gen( sz,tangling_steps,growing_steps )
% sz - size of one size of the maze expressed in the unmber of maze
% components - use values between 5 and 40 since those have a good chance
% of not making the generation process reasonably short.
%  tangling_steps - the number of steps in the tangeling process
%  growing_steps - the number of steps in the growing process
% 

t_set=...
{'Empty','End','Horizontal','Vertical','Left-Up','Left-Down','Right-Up','Right-Down',...
'Horizontal-New-Up','Horizontal-New-Down','Vertical-New-Left','Vertical-New-Right',...
'Start','Finish'};

elements(1:1:sz,1:1:sz)=N_from_s(t_set, 'Empty' );

elements(round(sz/2),1)=N_from_s(t_set, 'Start' );
elements(round(sz/2),2)=N_from_s(t_set, 'Horizontal' );
elements(round(sz/2),3)=N_from_s(t_set, 'Left-Down' );
elements(round(sz/2+1):1:(sz-2),3)=N_from_s(t_set, 'Vertical' );
elements(round(sz-1),3)=N_from_s(t_set, 'Right-Up' );

elements(round(sz-1),4:1:(sz-3))=N_from_s(t_set, 'Horizontal' );

elements(round(sz-1),sz-2)=N_from_s(t_set, 'Left-Up' );
elements(round(sz/2+1):1:(sz-2),sz-2)=N_from_s(t_set, 'Vertical' );
elements(round(sz/2),sz-2)=N_from_s(t_set, 'Right-Down' );
elements(round(sz/2),sz-1)=N_from_s(t_set, 'Horizontal' );
elements(round(sz/2),sz)=N_from_s(t_set, 'Finish' );

for n=1:1:(tangling_steps+growing_steps)
    
    if n<tangling_steps
        rand_num=ceil(rand()*16);
    end
    
    if n>tangling_steps
        rand_num=ceil(rand()*72);
    end

    img=[];
    img_replace=[];
    
    if rand_num==1
        %        
        %   XXXXXXXXX
        %
        %       TO
        %
        %      XXX   
        %   XXX   XXX
        %


        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' )];

        img_replace=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Right-Up' )];
    end

    if rand_num==2
        %      XXX
        %   XXX   XXX
        %
        %       TO
        %
        %         
        %   XXXXXXXXX
        %

        img=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Right-Up' )];


        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' )];

    end

    if rand_num==3
        %        
        %   XXXXXXXXX
        %
        %       TO
        %
        %            
        %   XXX   XXX
        %      XXX


        img=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];

        img_replace=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Right-Down' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Up' )];
    end

    if rand_num==4
        %         
        %   XXX   XXX
        %      XXX
        %       TO
        %
        %         
        %   XXXXXXXXX
        %

        img=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Right-Down' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Up' )];


        img_replace=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];

    end
    
    if rand_num==5
        %      XXX
        %   XXX   XXX
        %
        %       TO
        %
        %      XXX
        %     X   X
        %   XXX   XXX

        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Down' )];


        img_replace=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Vertical' )];

    end
    
    if rand_num==6
        %      XXX
        %     X   X
        %   XXX   XXX
        %       TO
        %
        %      XXX
        %   XXX   XXX
        %
        
        img=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Vertical' )];
        
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Down' )];

    end

    if rand_num==7
        %      
        %   XXX   XXX
        %      XXX
        %       TO
        %
        %   XXX   XXX
        %     X   X
        %      XXX

        img=[N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Up' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];


        img_replace=[N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Up' )];

    end
    
    if rand_num==8
        %      
        %   XXX   XXX
        %     X   X
        %      XXX
        %       TO
        %
        %   XXX   XXX
        %      XXX
        %       

        img=[N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Up' )];


        img_replace=[N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Up' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
    end
    
    if rand_num==9
        %     X   
        %     X
        %     X
        %     X
        %       TO
        %     X   
        %       X
        %       X
        %     X

        img=[N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' )];

        img_replace=[N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Up' )];
    end

    if rand_num==10
        %     X   
        %       X
        %       X
        %     X
        %       TO
        %     X   
        %     X
        %     X
        %     X

        img=[N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Up' )];
        
        img_replace=[N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' )];
    end    
    
    if rand_num==11
        %     X   
        %     X
        %     X
        %     X
        %       TO
        %     X   
        %   X
        %   X
        %     X

        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' )];

        img_replace=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Up' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Down' )];
    end
    
    if rand_num==12
        %     X   
        %   X
        %   X
        %     X
        %       TO
        %     X   
        %     X
        %     X
        %     X

        img=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Left-Up' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Left-Down' )];

        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' )];
    end    
  
      if rand_num==13
        %     X   
        %       X
        %       X
        %     X
        %       TO
        %     X   
        %         X
        %         X
        %     X

        img=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Up' )];
      end  

      if rand_num==14
        %     X   
        %        X
        %        X
        %     X
        %       TO
        %     X   
        %       X
        %       X
        %     X

        img=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Down' );...
            N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Up' )];
        
        img_replace=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Empty' )];
      end       

    if rand_num==15
        %     X   
        %   X
        %   X
        %     X
        %       TO
        %     X   
        %  X
        %  X
        %     X
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Down' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Up' )];
        
        img_replace=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Horizontal' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Horizontal' )];
    end      

    if rand_num==16
        %     X   
        %   X
        %   X
        %     X
        %       TO
        %     X   
        %  X
        %  X
        %     X
        
        img=[N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Horizontal' );...
            N_from_s(t_set, 'Right-Up' ) N_from_s(t_set, 'Horizontal' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Down' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Up' )];
    end        

    if rand_num==17
        %        
        %     XXXXXXX
        %     
        %     
        %       TO
        %
        %        X
        %        X
        %     XXXXXXX
        %     
        %     
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal' )];
        
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal-New-Up' )];
    end        

    if rand_num==18
        %
        %        X
        %        X
        %     XXXXXXX
        %     
        %       
        %       TO
        %
        %        
        %        
        %     XXXXXXX
        %     
        %     
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal-New-Up' )];
        
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal' )];
    end   
    
    if rand_num==19
        %        
        %     XXXXXXX
        %     
        %     
        %       TO
        %
        %        
        %        
        %     XXXXXXX
        %        X
        %        X
        
        img=[N_from_s(t_set, 'Horizontal' );...
            N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal-New-Down' );...
            N_from_s(t_set, 'Empty' )];
    end     
      
    if rand_num==20
        %        
        %     XXXXXXX
        %        X
        %        X
        %
        %       TO
        %
        %        
        %        
        %     XXXXXXX
        %        
        %        
        
        img=[N_from_s(t_set, 'Horizontal-New-Down' );
            N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal' );
            N_from_s(t_set, 'Empty' )];
    end 
    
    if rand_num==21
        %       X 
        %       X
        %       X
        %       
        %       TO
        %
        %        X
        %     XXXX
        %        X
        %        
        %     
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical-New-Left' )];
    end   

    
    if rand_num==22
        %       X 
        %    XXXX
        %       X
        %       
        %       TO
        %
        %        X
        %        X
        %        X
        %        
        %     
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical-New-Left' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' )];
    end   
        
    if rand_num==23
        %       X 
        %       X
        %       X
        %       
        %       TO
        %
        %        X
        %        XXXX
        %        X
        %        
        %     
        
        img=[ N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[ N_from_s(t_set, 'Vertical-New-Right' ) N_from_s(t_set, 'Empty' )];
    end   
        
    if rand_num==24
        %       X 
        %       XXXX
        %       X
        %       
        %       TO
        %
        %        X
        %        X
        %        X
        %        
        %     
        
        img=[N_from_s(t_set, 'Vertical-New-Right' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' )];
    end   
   
    if rand_num==25
        %         
        %         X
        %       XXXXX      
        %       
        %       TO
        %         X
        %         X   
        %         X 
        %       XXXXX   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal-New-Up' )];
        
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Horizontal-New-Up' )];
    end       

    if rand_num==26
        %         X
        %         X       
        %         X
        %       XXXXX      
        %       
        %       TO
        %         
        %            
        %         X 
        %       XXXXX   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Horizontal-New-Up' )];
        
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal-New-Up' )];
    end       
  
    if rand_num==27
        %         
        %       XXXXX
        %         X      
        %       
        %       TO
        %       XXXXX
        %         X   
        %         X 
        %         X  
        
        img=[N_from_s(t_set, 'Horizontal-New-Down' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal-New-Down' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' )];
    end  

    if rand_num==28
        %         
        %       XXXXX
        %         X      
        %         X
        %         X
        %       TO
        %       XXXXX
        %         X   
        %          
        %          
        
        img=[N_from_s(t_set, 'Horizontal-New-Down' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal-New-Down' )
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' )];
    end     
 
    if rand_num==29
        %       X
        %    XXXX
        %       X      
        %         
        %       TO
        %         
        %       X
        %  XXXXXX
        %       X   
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical-New-Left' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Vertical-New-Left' )];
    end
  
    if rand_num==30
        %       X
        %  XXXXXX
        %       X      
        %         
        %       TO
        %         
        %       X
        %     XXX
        %       X   
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Vertical-New-Left' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical-New-Left' )];
    end 
        
    if rand_num==31
        %       X
        %       XXXX
        %       X      
        %         
        %       TO
        %         
        %       X
        %       XXXXXXX
        %       X   
        
        img=[N_from_s(t_set, 'Vertical-New-Right' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Vertical-New-Right' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
     end
         
    if rand_num==32
        %       X
        %       XXXXXXX
        %       X      
        %         
        %       TO
        %         
        %       X
        %       XXXX
        %       X   
        
        img=[N_from_s(t_set, 'Vertical-New-Right' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Vertical-New-Right' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
    end

      if rand_num==33
        %         
        %         X
        %         X     
        %       
        %       TO
        %         X
        %         X   
        %         X 
        %         X   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' )];
        
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Vertical' )];
    end       

    if rand_num==34
        %         X
        %         X       
        %         X
        %         X      
        %       
        %       TO
        %         
        %            
        %         X 
        %         X   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Vertical' )];
        
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' )];
    end       
  
    if rand_num==35
        %         
        %         X
        %         X      
        %       
        %       TO
        %         X
        %         X   
        %         X 
        %         X  
        
        img=[N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' )];
    end  

    if rand_num==36
        %         
        %         X
        %         X      
        %         X
        %         X
        %       TO
        %         X
        %         X   
        %          
        %          
        
        img=[N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Vertical' );...
            N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' )];
    end     
 
    if rand_num==37
        %       
        %    XXXX
        %             
        %         
        %       TO
        %         
        %       
        %  XXXXXX
        %          
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' )];
    end
  
    if rand_num==38
        %       
        %  XXXXXX
        %             
        %         
        %       TO
        %         
        %       
        %     XXX
        %          
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' )];
    end 
        
    if rand_num==39
        %       
        %       XXXX
        %             
        %         
        %       TO
        %         
        %       
        %       XXXXXXX
        %         
        
        img=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
     end
         
    if rand_num==40
        %       
        %       XXXXXXX
        %            
        %         
        %       TO
        %         
        %       
        %       XXXX
        %        
        
        img=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
    end  

      if rand_num==41
        %         
        %         X
        %         X     
        %         X
        %       TO
        %      XXXX
        %         X   
        %         X
        %            
        
        img=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' )  N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' )  N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Down' )];
      end      
 
      if rand_num==42
        %         
        %      XXXX
        %         X     
        %         X
        %       TO
        %         X
        %         X   
        %         X
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Down' )];
        
        img_replace=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
             N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' )];
    end      

      if rand_num==43
        %         
        %         X
        %         X     
        %         X
        %       TO
        %         XXXX
        %         X   
        %         X
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
      end      
 
      if rand_num==44
        %         
        %         XXXX
        %         X     
        %         X
        %       TO
        %         X
        %         X   
        %         X
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end
      
        if rand_num==45
        %         
        %         X
        %         X     
        %         X
        %       TO
        %         X
        %         X   
        %      XXXX
        %            
        
        img=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' ); ...
            N_from_s(t_set, 'Empty' )  N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Up' );...
           N_from_s(t_set, 'Empty' )  N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end      
 
      if rand_num==46
        %         
        %         X
        %         X     
        %      XXXX
        %       TO
        %         X
        %         X   
        %         X
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Left-Up' );...
           N_from_s(t_set, 'Empty' )  N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' ); ...
            N_from_s(t_set, 'Empty' )  N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
    end      

      if rand_num==47
        %         
        %         X
        %         X     
        %         X
        %       TO
        %         X
        %         X   
        %         XXXX
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
      end      
 
      if rand_num==48
        %         
        %         X
        %         X     
        %         XXXX
        %       TO
        %         X
        %         X   
        %         X
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Right-Down' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end
      
      if rand_num==49
        %         
        %         
        %      XXX     
        %         
        %       TO
        %      XXXXX
        %          X   
        %          X
        %            
        
        img=[ N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end    
 
      if rand_num==50
        %         
        %      XXXXX   
        %          X 
        %          X
        %       TO
        %      XXXXX
        %             
        %          
        %            

        img=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Empty' ); ...
           N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' ); ...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[ N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end    
      
      if rand_num==51
        %         
        %         
        %      XXX     
        %         
        %       TO
        %      
        %            X 
        %            X
        %      XXXXXXX      
        
        img=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' );];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Empty' )];
      end 
      
      if rand_num==52
        %            X 
        %            X
        %      XXXXXXX     
        %         
        %       TO
        %      
        %             
        %            
        %      XXX      
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
           N_from_s(t_set, 'Vertical' ) N_from_s(t_set, 'Empty' ); ...
           N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Empty' )];
        
        img_replace=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
      end
      
      if rand_num==53
        %         
        %         
        %         XXX     
        %         
        %       TO
        %      XXXX
        %      X   
        %      X
        %            
        
        img=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Down' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end  

      if rand_num==54
        %      XXXX
        %      X   
        %      X
        %              
        %       TO
        %      
        %         
        %      XXX
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Down' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
       
        img_replace=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );];
      end  
      
      if rand_num==55
        %         
        %         
        %         XXX     
        %         
        %       TO
        %      X
        %      X   
        %      XXXX
        %            
        
        img=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' );];
        
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Up' )];
      end        
      
      if rand_num==56
        %         
        %         
        %         XXX     
        %         
        %       TO
        %      X
        %      X   
        %      XXXX
        %            
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Up' )];
       
        img_replace=[ N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ); ...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' )];
        
      end        
      
      if rand_num==57
        %         
        %     XXXX    
        %        X     
        %         
        %       TO
        %         X
        %         X
        %      XXXX
        %         X   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Left-Down' )];
       
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Vertical-New-Left' )];
        
      end     
      
      if rand_num==58
        %         X
        %         X
        %      XXXX
        %         X          
        %       TO
        %         
        %         
        %      XXXX
        %         X   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Vertical-New-Left' )];
       
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Left-Down' )];
        
      end    
      
      if rand_num==59
        %        X 
        %     XXXX    
        %             
        %         
        %       TO
        %         
        %         X
        %      XXXX
        %         X   
        %         X
        img=[N_from_s(t_set, 'Left-Up' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Vertical-New-Left' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' )];
        
      end   
       
      if rand_num==60
        %        X 
        %     XXXX    
        %        X     
        %        X 
        %       TO
        %         
        %         X
        %      XXXX
        %         
        %         
        
        img=[N_from_s(t_set, 'Vertical-New-Left' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Left-Up' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' )];
      end   
      
          if rand_num==61
        %         
        %        XXXX    
        %        X     
        %         
        %       TO
        %         X
        %         X
        %         XXXX
        %         X   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Right-Down' )];
       
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Vertical-New-Right' )];
        
      end     
      
      if rand_num==62
        %         X
        %         X
        %         XXXX
        %         X          
        %       TO
        %         
        %         
        %         XXXX
        %         X   
        
        img=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Vertical-New-Right' )];
       
        img_replace=[N_from_s(t_set, 'Empty' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Right-Down' )];
        
      end    
      
      if rand_num==63
        %        X 
        %        XXXX    
        %             
        %         
        %       TO
        %         
        %         X
        %         XXXX
        %         X   
        %         X
        img=[N_from_s(t_set, 'Right-Up' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Vertical-New-Right' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' )];
        
      end   
       
      if rand_num==64
        %        X 
        %        XXXX    
        %        X     
        %        X 
        %       TO
        %         
        %         X
        %         XXXX
        %         
        %         
        
        img=[N_from_s(t_set, 'Vertical-New-Right' );...
            N_from_s(t_set, 'Vertical' );...
           N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Right-Up' );...
            N_from_s(t_set, 'Empty' );...
           N_from_s(t_set, 'Empty' )];
      end  

     if rand_num==65
        %         
        %     XXXX    
        %        X     
        %         
        %       TO
        %         
        %         
        %      XXXXXXX
        %         X   
        
        img=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Horizontal-New-Down' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
      end     
      
      if rand_num==66
        %         
        %         
        %      XXXXXXX
        %         X          
        %       TO
        %         
        %         
        %      XXXX
        %         X   
        
        img=[N_from_s(t_set, 'Horizontal-New-Down' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Left-Down' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
        
      end    
      
      if rand_num==67
        %        X 
        %     XXXX    
        %             
        %         
        %       TO
        %         
        %         X
        %      XXXXXXX
        %            
        %         
        img=[N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Horizontal-New-Up' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
        
      end   
       
      if rand_num==68
        %        X 
        %     XXXXXXX    
        %             
        %         
        %       TO
        %         
        %         X
        %      XXXX
        %         
        %         
        
        img=[N_from_s(t_set, 'Horizontal-New-Up' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Empty' )];
       
        img_replace=[N_from_s(t_set, 'Left-Up' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' )];
      end   
      
          if rand_num==69
        %         
        %        XXXX    
        %        X     
        %         
        %       TO
        %         
        %         
        %      XXXXXXX
        %         X   
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Down' )];
       
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal-New-Down' )];
        
      end     
      
      if rand_num==70
        %         
        %         
        %      XXXXXXX
        %         X          
        %       TO
        %         
        %         
        %         XXXX
        %         X   
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal-New-Down' )];
       
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Down' )];
        
      end    
      
      if rand_num==71
        %        X 
        %        XXXX    
        %             
        %         
        %       TO
        %         
        %         X
        %      XXXXXXX
        %            
        %         
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Up' )];
       
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal-New-Up' )];
        
      end   
       
      if rand_num==72
        %        X 
        %     XXXXXXX    
        %             
        %         
        %       TO
        %         
        %         X
        %         XXXX
        %         
        %         
        
        img=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Right-Up' )];
       
        img_replace=[N_from_s(t_set, 'Empty' ) N_from_s(t_set, 'Horizontal' ) N_from_s(t_set, 'Horizontal-New-Up' )];
      end        
      
      elements=Find_and_replace( elements, img, img_replace );

end


end

